import json
import urllib.parse

class ExecuteService():
    def __init__(self):
        super().__init__()

    def request(self, driver, url, method="POST", params=None, data=None, headers=None):
        '''
        @Desc    : 请求
        @Author  : 钟水洲
        @Time    : 2024/05/31 15:42:22
        '''
        # 请求方式转大写
        method = method.upper()

        # 拼接URL参数
        if params:
            query_string = urllib.parse.urlencode(params)
            separator = '&' if '?' in url else '?'
            url = f"{url}{separator}{query_string}"

        # 默认请求内容
        if data is None:
            data = {}

        # 请求头
        if headers is None:
            headers = {
                "content-type": "application/json"
            }

        # 请求内容
        body = json.dumps(json.dumps(data, ensure_ascii=False), ensure_ascii=False)

        js_script = f"""
            const done = arguments[0];
            (async () => {{
                try {{
                    const res = await fetch("{url}", {{
                        method: "{method}",
                        credentials: "include",
                        mode: "cors",
                        headers: {headers},
                        referrer: document.referrer,
                        referrerPolicy: "strict-origin-when-cross-origin",
                        {"body: " + body + "," if method != "GET" else ""}
                    }});
                    const text = await res.text();
                    done(text);
                }} catch (e) {{
                    done("ERROR: " + e.toString());
                }}
            }})();
        """

        return driver.execute_async_script(js_script)

    def request_file(self, driver, url, file_url, method="POST", params=None, data=None, headers=None):
        '''
        @Desc    : 请求
        @Author  : 钟水洲
        @Time    : 2024/05/31 15:42:22
        '''
        method = method.upper()

        # 拼接 URL 查询参数
        if params:
            query_string = urllib.parse.urlencode(params)
            url = f"{url}?{query_string}" if "?" not in url else f"{url}&{query_string}"

        if data is None:
            data = {}

        # 默认请求头（浏览器会自动设置 multipart/form-data 的 boundary）
        if headers is None:
            headers = {}  # 不要手动设置 Content-Type，浏览器会自动处理

        # 构造 JS 可用的 data 键值对
        form_data_entries = [f'["{key}", "{value}"]' for key, value in data.items()]

        js_script = f"""
            const done = arguments[0];
            (async () => {{
                try {{
                    // 获取文件
                    let formData = new FormData();
                    const fileResponse = await fetch("{file_url}");
                    const blob = await fileResponse.blob();
                    formData.append("data", blob);

                    // 添加表单参数
                    const formParams = [{", ".join(form_data_entries)}];
                    formParams.forEach(([key, value]) => {{
                        formData.append(key, value);
                    }});

                    // 发送请求
                    const res = await fetch("{url}", {{
                        method: "{method}",
                        headers: {headers},
                        body: formData,
                    }});
                    const text = await res.text();
                    done(text);
                }} catch (e) {{
                    done("ERROR: " + e.toString());
                }}
            }})();
        """
        return driver.execute_async_script(js_script)


import json
from rpa_common import Env
from rpa_common.library.Request import Request

env = Env()
request = Request()

class TaskRequest():
    def __init__(self):
        super().__init__()

        env_data = env.get()
        self.host = env_data['api']

    def getTaskShopList(self):
        '''
        @Desc    : 获取任务店铺列表
        @Author  : 钟水洲
        @Time    : 2024/05/31 15:42:22
        '''
        print("获取任务店铺列表 strat")
        url = self.host + '/api/v2/index/post?c=task&a=getTaskShopList&zsit=debug'
        res = request.post(url, {})
        print("获取任务店铺列表 end", res)
        return res

    def getShopTask(self, data):
        '''
        @Desc    : 获取任务店铺列表
        @Author  : 钟水洲
        @Time    : 2024/05/31 15:42:22
        '''
        print("获取店铺任务 strat")
        url = self.host + '/api/v2/index/post?c=task&a=getShopTask&zsit=debug'
        res = request.post(url, data)
        print("获取店铺任务 end", res)
        return res

    def getTask(self, data):
        '''
        @Desc    : 获取任务信息
        @Author  : 钟水洲
        @Time    : 2024/05/31 15:42:22
        '''
        print("获取任务信息 strat")

        url = self.host + '/api/v2/index/post?c=task&a=getTaskInfo&zsit=debug'
        res = request.post(url, data)
        print("获取任务信息 end", res)
        return res

    def save(self, data):
        '''
        @Desc    : 保存数据
        @Author  : 钟水洲
        @Time    : 2024/05/31 15:42:22
        '''
        print("保存数据 strat")
        url = self.host + '/api/v2/index/post?c=data&a=storage&zsit=debug'
        res = request.post(url, data)
        print("保存数据 end", res)
        return res

    def end(self, data):
        '''
        @Desc    : 完成任务
        @Author  : 钟水洲
        @Time    : 2024/05/31 15:42:22
        '''
        print("完成任务 strat")
        url = self.host + '/api/v2/index/post?c=task&a=completeTask&zsit=debug'
        res = request.post(url, data)
        print("完成任务 end", res)
        return res

    def error(self, data):
        '''
        @Desc    : 任务失败
        @Author  : 钟水洲
        @Time    : 2024/05/31 15:42:22
        '''
        print("任务失败 strat")
        url = self.host + '/api/v2/index/post?c=task&a=failedTask&zsit=debug'
        res = request.post(url, data)
        print("任务失败 end", res)
        return res


import pyotp

from rpa_common import Common
from rpa_common.exceptions import GoogleAuthException

common = Common()

class GoogleService():
    def __init__(self):
        super().__init__()

    @staticmethod
    def get_verify_code(secret_key):
        '''
        @Desc    : 获取验证码
        @Author  : 钟水洲
        @Time    : 2024/05/31 15:42:22
        '''
        print('secret_key', secret_key)
        if not secret_key:
            raise GoogleAuthException("谷歌验证器秘钥不能为空")

        # 创建 TOTP 对象
        totp = pyotp.TOTP(secret_key)

        # 获取当前验证码
        current_otp = totp.now()

        return common.back(1, '获取成功', current_otp)


# 参数异常

from .Base import BaseAppException

class IpException(BaseAppException):
    def __init__(self, error_msg="IP异常", error_response=None):
        super().__init__(error_msg, error_response, "41000")

class EmailException(BaseAppException):
    def __init__(self, error_msg="邮箱异常", error_response=None):
        super().__init__(error_msg, error_response, "42000")

class TaskParamsException(BaseAppException):
    def __init__(self, error_msg="任务参数异常", error_response=None):
        super().__init__(error_msg, error_response, "43000")

class GoogleAuthException(BaseAppException):
    def __init__(self, error_msg="谷歌验证器异常", error_response=None):
        super().__init__(error_msg, error_response, "44000")


# __init__.py

# 空文件，表示这是一个包

from Chrome import Chrome
from Request import Request
from Crontab import Crontab
from Decorator import retry, singleton
from Env import Env
from Logger import Logger
from Queue import Queue
from Request import Request
from Task import Task
from Run import Run